<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar_JO">
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="442"/>
        <location filename="../../CopyEngine.cpp" line="465"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>تم إجبار المحرك على الحركة ، لا يمكنك نسخه</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="519"/>
        <location filename="../../CopyEngine.cpp" line="542"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>تم إجبار المحرك على النسخ ، لا يمكنك التحرك معه</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Destination</source>
        <translation>الوجهه</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>استخدام الوجهة الفعلية  &quot;%1&quot; ؟</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="731"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>تم فرض الوضع مسبقا. هذا خطا داخلي ، الرجاء الإبلاغ عنه</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="886"/>
        <source>Supported only on Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1035"/>
        <location filename="../../CopyEngine.cpp" line="1038"/>
        <location filename="../../CopyEngine.cpp" line="1043"/>
        <location filename="../../CopyEngine.cpp" line="1047"/>
        <source>Ask</source>
        <translation>اسال</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1036"/>
        <location filename="../../CopyEngine.cpp" line="1040"/>
        <location filename="../../CopyEngine.cpp" line="1044"/>
        <location filename="../../CopyEngine.cpp" line="1048"/>
        <source>Skip</source>
        <translation>تخطي</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1039"/>
        <source>Merge</source>
        <translation>دمج</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1041"/>
        <location filename="../../CopyEngine.cpp" line="1053"/>
        <source>Rename</source>
        <translation>اعاده تسميه</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1045"/>
        <source>Put at the end</source>
        <translation>وضع في نهاية</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1049"/>
        <source>Overwrite</source>
        <translation>الكتابة فوق</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1050"/>
        <source>Overwrite if different</source>
        <translation>الكتابة فوق إذا كان مختلفا</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1051"/>
        <source>Overwrite if newer</source>
        <translation>الكتابة فوق إذا كان أحدث</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1052"/>
        <source>Overwrite if older</source>
        <translation>الكتابة فوق إذا كان أقدم</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options error</source>
        <translation>خطا في الخيارات</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>لم يتم تحميل محرك الخيارات. غير قادر علي الوصول إلى الفلاتر</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="60"/>
        <location filename="../../CopyEngineFactory.cpp" line="309"/>
        <source>Supported only on Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Ask</source>
        <translation>اسال</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Skip</source>
        <translation>تخطي</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Merge</source>
        <translation>دمج</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <location filename="../../CopyEngineFactory.cpp" line="454"/>
        <source>Rename</source>
        <translation>اعاده تسميه</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="446"/>
        <source>Put at the end</source>
        <translation>وضع في نهاية</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="450"/>
        <source>Overwrite</source>
        <translation>الكتابة فوق</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="451"/>
        <source>Overwrite if different</source>
        <translation>الكتابة فوق إذا كان مختلفا</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="452"/>
        <source>Overwrite if newer</source>
        <translation>الكتابة فوق إذا كان أحدث</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="453"/>
        <source>Overwrite if older</source>
        <translation>الكتابة فوق إذا كان أقدم</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options error</source>
        <translation>خطا في الخيارات</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>لم يتم تحميل محرك الخيارات. غير قادر علي الوصول إلى الفلاتر</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>لم يتم تحميل محرك الخيارات. غير قادر علي الوصول إلى الفلاتر</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>مساحة القرص</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>تحتاج مساحة أكبر على محرك الاقراص هذا لإنهاء هذا النقل</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>مواصله</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>إلغاء الأمر</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>تتوفر %2 محركات الاقراص %1 ولكن تحتاج %3</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="92"/>
        <source>Error on folder</source>
        <translation>خطأ في المجلد</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="95"/>
        <source>Folder name</source>
        <translation>اسم المجلد</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="201"/>
        <source>%name% - copy%suffix%</source>
        <translation>% اسم%-نسخ% لاحقه%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="208"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>(% الاسم%-النسخ (% العدد%% اللاحق +ه%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Try rename with using special characters</source>
        <translation>حاول أعاده تسميه باستخدام أحرف خاصه</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="145"/>
        <source>%name% - copy%suffix%</source>
        <translation>% اسم%-نسخ% لاحقه%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="152"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>(% الاسم%-النسخ (% العدد%% اللاحق +ه%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Try rename with using special characters</source>
        <translation>حاول أعاده تسميه باستخدام أحرف خاصه</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>بحث:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>نوع البحث:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>نص خام</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Simplified regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>تنطبق على:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>ملف</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>ملف ومجلد</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>سلسله اختبار يطابق مع regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>التحقق</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>سلسله الاختبار:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>حوار الفلاتر</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>يجب ان تتطابق السلسلة الكاملة</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>regex صالحة</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>فلاتر</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="39"/>
        <source>Exclusion filters</source>
        <translation>فلاتر الاستبعاد</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="111"/>
        <source>Inclusion filters</source>
        <translation>فلاتر مدرجة</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="132"/>
        <source>None = Include all</source>
        <translation>بلا = تضمين الكل</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="94"/>
        <location filename="../../Filters.cpp" line="132"/>
        <source>Raw text</source>
        <translation>نص خام</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="97"/>
        <location filename="../../Filters.cpp" line="135"/>
        <source>Simplified regex</source>
        <translation>المبسطة regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="100"/>
        <location filename="../../Filters.cpp" line="138"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="108"/>
        <location filename="../../Filters.cpp" line="146"/>
        <source>Only on file</source>
        <translation>فقط في الملف</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="111"/>
        <location filename="../../Filters.cpp" line="149"/>
        <source>Only on folder</source>
        <translation>فقط في المجلد</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="117"/>
        <location filename="../../Filters.cpp" line="155"/>
        <location filename="../../Filters.cpp" line="217"/>
        <location filename="../../Filters.cpp" line="256"/>
        <source>Full match</source>
        <translation>تطابق كامل</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="91"/>
        <source>Folder already exists</source>
        <translation>المجلد موجود بالفعل</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="172"/>
        <source>%name% - copy%suffix%</source>
        <translation>% اسم%-نسخ% لاحقه%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="181"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>(% الاسم%-النسخ (% العدد%% اللاحق +ه%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Try rename with using special characters</source>
        <translation>حاول أعاده التسميه باستخدام أحرف خاصه</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="242"/>
        <location filename="../../ListThreadListChange.cpp" line="413"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>غير قادر علي القيام بنقل المادة أو نسخه إلى وضع إجباري غير صحيح: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="249"/>
        <location filename="../../ListThreadListChange.cpp" line="420"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>غير قادر على حفظ قائمه النقل: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="270"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>مشكلة في قراءة الملف ، أو حجم الملف هو 0</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="277"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>العنوان الرأسي الخاطئ: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="286"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>قائمة النقل في الوضع المختلط ، ولكن هذا المثيل ليس في هذا الوضع</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="295"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>قائمه النقل في وضع النسخ ولكن هذا المثيل غير في هذا الوضع</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="301"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>قائمه النقل في وضع النقل ، ولكن هذا المثيل ليس في هذا الوضع</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="365"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>عثر على بعض الأخطاء اثناء تحليل الخط</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="373"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>غير قادر على فتح قائمه النقل: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="187"/>
        <location filename="../../MkPath.cpp" line="210"/>
        <location filename="../../MkPath.cpp" line="315"/>
        <location filename="../../MkPath.cpp" line="363"/>
        <source>Unable to create the folder</source>
        <translation>غير قادر على إنشاء المجلد</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="227"/>
        <source>The source folder don&apos;t exists</source>
        <translation>مجلد المصدر غير موجود</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="304"/>
        <source>Unable to temporary rename the folder</source>
        <translation>غير قادر على أعاده تسميه المجلد المؤقت</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="339"/>
        <source>Unable to reverse temporary rename for real move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="348"/>
        <source>Unable to do the final real move the folder</source>
        <translation>غير قادر على القيام بالخطوة الحقيقية النهائية المجلد</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="379"/>
        <source>Unable to move the folder</source>
        <translation>غير قادر على نقل المجلد</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="385"/>
        <source>Unable to move the folder: errno: %1</source>
        <translation>errno: %1 :غير قادر على نقل المجلد</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="124"/>
        <location filename="../../MkPath.cpp" line="464"/>
        <source>Unable to remove</source>
        <translation>غير قادر على أزاله</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../async/ReadThread.cpp" line="78"/>
        <source>Internal error, please report it!</source>
        <translation>خطا داخلي ، يرجى الإبلاغ عن ذلك!</translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="543"/>
        <source>Unable to read the source file: </source>
        <translation>غير قادر على قراءه الملف المصدر:</translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="599"/>
        <source>File truncated during the read, possible data change</source>
        <translation>تم اقتطاع الملف اثناء القراءة ، وتغيير البيانات المحتملة</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>أعاده التسمية الاولي</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation>% اسم%-نسخ% لاحقه%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>% الاسم%-النسخ (% العدد%% اللاحق +ه%)</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;لاحقه الملف&lt;/span&gt;%لاحقه%&lt;span style=&quot; font-weight:600;&quot;&gt;للعدد الإضافي ،&lt;/span&gt;%عدد%&lt;span style=&quot; font-weight:600;&quot;&gt;لاسم الملف الأصلي ،&lt;/span&gt;%اسم%&lt;span style=&quot; font-weight:600;&quot;&gt;المتغيرات: &lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>أعاده تسميه ثانيه</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>أعاده تسميه القواعد</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="46"/>
        <location filename="../../RenamingRules.cpp" line="71"/>
        <source>%1 - copy%2</source>
        <translation>%1 - نسخ (%2)</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="50"/>
        <location filename="../../RenamingRules.cpp" line="84"/>
        <source>%1 - copy (%2)%3</source>
        <translation>%1-نسخ (%2) %3</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="331"/>
        <location filename="../../ScanFileOrFolder.cpp" line="681"/>
        <source>Blacklisted folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="463"/>
        <location filename="../../ScanFileOrFolder.cpp" line="465"/>
        <source>%1 - copy</source>
        <translation>%1-نسخ</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="474"/>
        <location filename="../../ScanFileOrFolder.cpp" line="476"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - نسخ (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
        <source>%name% - copy</source>
        <translation>%اسم% - نسخ</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="598"/>
        <location filename="../../ScanFileOrFolder.cpp" line="600"/>
        <source>%name% - copy (%number%)</source>
        <translation>% الاسم%-النسخة (% العدد%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="691"/>
        <location filename="../../ScanFileOrFolder.cpp" line="695"/>
        <source>Problem with folder read</source>
        <translation>مشكله في قراءه المجلد</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="628"/>
        <source>%name% - copy%suffix%</source>
        <translation>% اسم%-نسخ% لاحقه%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="635"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>(% الاسم%-النسخ (% العدد%% اللاحق +ه%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="663"/>
        <location filename="../../TransferThread.cpp" line="904"/>
        <source>File not found</source>
        <translation>الملف غير موجود</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="904"/>
        <location filename="../../TransferThread.cpp" line="940"/>
        <source>Unable to change the date</source>
        <translation>غير قادر على تغيير التاريخ</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="188"/>
        <source>Try rename with using special characters</source>
        <translation>حاول أعاده تسميه باستخدام أحرف خاصه</translation>
    </message>
</context>
<context>
    <name>TransferThreadAsync</name>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="342"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation>تاريخ تعديل خاطئ أو غير قادر علي الحصول عليه ، يمكنك تعطيل نقل الوقت للقيام بذلك</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="436"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="454"/>
        <source>Unable to create the destination folder: </source>
        <translation type="unfinished">غير قادر على إنشاء مجلد الوجهة:</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="439"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="456"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation type="unfinished">errno: %1 غير قادر علي إنشاء المجلد الوجهة</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../async/WriteThread.cpp" line="138"/>
        <source>Path resolution error (Empty path)</source>
        <translation>(خطأ في دقة المسار (مسار فارغ</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="167"/>
        <location filename="../../async/WriteThread.cpp" line="200"/>
        <source>Unable to create the destination folder: </source>
        <translation>غير قادر على إنشاء مجلد الوجهة:</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="178"/>
        <location filename="../../async/WriteThread.cpp" line="202"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation>errno: %1 غير قادر علي إنشاء المجلد الوجهة</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="464"/>
        <source>Internal error, please report it!</source>
        <translation>خطا داخلي ، يرجى الإبلاغ عن ذلك!</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>نقل</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="63"/>
        <source>Move the whole folder</source>
        <translation>نقل المجلد بأكمله</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="97"/>
        <source>Transfer the file rights</source>
        <translation>نقل حقوق الملف</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="76"/>
        <source>Keep the file date</source>
        <translation>الاحتفاظ بتاريخ الملف</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="114"/>
        <source>Create full path if not exists</source>
        <translation>إنشاء مسار كامل إذا لم يكن موجودا</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="138"/>
        <source>Checksum</source>
        <translation>اختباري </translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Auto start</source>
        <translation>البدء التلقائي</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="154"/>
        <source>Error and collision</source>
        <translation>الخطا والاصطدام</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="160"/>
        <source>When folder error</source>
        <translation>عند خطا في المجلد</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="170"/>
        <source>When file error</source>
        <translation>عند خطا في الملف</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="196"/>
        <source>When file collision</source>
        <translation>عندما تتضارب الملفات</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="239"/>
        <source>Overwrite if not same size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="244"/>
        <source>Overwrite if modification date differs</source>
        <translation type="unfinished">الكتابة فوق إذا اختلف تاريخ التعديل</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="266"/>
        <source>When folder collision</source>
        <translation>عندما يتضارب المجلد</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="297"/>
        <source>Check if destination folder exists</source>
        <translation>تحقق مما إذا كان مجلد الوجهة موجودا</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="304"/>
        <source>Renaming rules</source>
        <translation>أعاده تسميه القواعد</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="324"/>
        <source>Delete partially transferred files</source>
        <translation>حذف الملفات المنقولة جزئيا</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="337"/>
        <source>Rename the original destination</source>
        <translation>أعاده تسميه الوجهة الاصليه</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="368"/>
        <source>Performance</source>
        <translation>الاداء</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="387"/>
        <source>Inode threads</source>
        <translation>Inode threads</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="397"/>
        <location filename="../../copyEngineOptions.ui" line="413"/>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="429"/>
        <source>Uncheck this under Windows create problem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="436"/>
        <source>OS Buffer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="456"/>
        <source>Disable parallel transfer when are different devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="463"/>
        <source>Buffer for different device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="470"/>
        <source>OS FLags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="477"/>
        <source>Buffer for same device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="484"/>
        <source>OS native copy (disable speed limitation)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="514"/>
        <source>Misc</source>
        <translation>متفرقات</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="520"/>
        <source>Check the disk space</source>
        <translation>تحقق من مساحة القرص</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="530"/>
        <source>Use this folder when destination is not set</source>
        <translation>استخدم هذا المجلد عندما لا يتم تعيين الوجهة</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="542"/>
        <source>Browse</source>
        <translation>استعراض </translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="564"/>
        <source>Filters</source>
        <translation>فلاتر</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>خطا في الملف</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>حجم</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>معدل</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>الوجهه</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp; تنفيذ هذا الاجراء دوما</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>جرب مع الامتيازات المرتفعة</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>وضع إلى أسفل</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>اعاده المحاوله</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>الملف موجود</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>الوجهه</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>حجم</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>معدل</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>اقتراح &amp;اسم جديد</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp; تنفيذ هذا الاجراء دوما</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if source newer than destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>الكتابة فوق إذا اختلف تاريخ التعديل</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <source>Overwrite if source older than destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if destination older</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="362"/>
        <location filename="../../fileExistsDialog.ui" line="365"/>
        <source>Overwrite if not same size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="370"/>
        <location filename="../../fileExistsDialog.ui" line="373"/>
        <source>Overwrite if not same size and date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;اعاده تسميه</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;الكتابة فوق</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>حجم</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>معدل</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>المصدر والوجهة متشابهان</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>اقتراح &amp;اسم جديد</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp; تنفيذ هذا الاجراء دوما</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;اعاده تسميه</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>الوجهه</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>المصدر والوجهة متطابقان</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>معدل</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>اسم المجلد</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>اقتراح &amp;اسم جديد</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp; تنفيذ هذا الاجراء دوما</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;اعاده تسميه</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>دمج</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>تخطي</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
</context>
</TS>
